Moodle String Generator package
===============================

.. toctree::
   :maxdepth: 4

Math module
-----------

Math base subpackage
~~~~~~~~~~~~~~~~~~~~

.. automodule:: moodlesg.math.base
   :members:
   :undoc-members:
   :show-inheritance:

Math functions subpackage
~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: moodlesg.math.functions
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: moodlesg.math.functions.common
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: moodlesg.math.functions.extended
   :members:
   :undoc-members:
   :show-inheritance:

Math constants subpackage
~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: moodlesg.math.constants.common
   :members:
   :undoc-members:
   :show-inheritance:
